@@ -4,6 +4,7 @@
 // license that can be found in the LICENSE file.
 //
 
+//go:build darwin
 // +build darwin
 
 package serial
@@ -19,12 +20,11 @@ import (
 )
 
 func (p *Port) retrieveTermSettings() (*settings, error) {
-	var err error
 	s := &settings{termios: new(unix.Termios), specificBaudrate: 0}
 
-	s.termios, err = unix.IoctlGetTermios(p.internal.handle, unix.TIOCGETA)
-	if err != nil {
-		return nil, newOSError(err)
+	var err error
+	if s.termios, err = unix.IoctlGetTermios(p.internal.handle, unix.TIOCGETA); err != nil {
+		return nil, newPortOSError(err)
 	}
 
 	speed := C.cfgetispeed((*C.struct_termios)(unsafe.Pointer(s.termios)))
@@ -35,11 +35,12 @@ func (p *Port) retrieveTermSettings() (*settings, error) {
 
 func (p *Port) applyTermSettings(s *settings) error {
 	if err := unix.IoctlSetTermios(p.internal.handle, unix.TIOCSETA, s.termios); err != nil {
-		return newOSError(err)
+		return newPortOSError(err)
 	}
 
-	if err := unix.IoctlSetInt(p.internal.handle, C.IOSSIOSPEED, s.specificBaudrate); err != nil {
-		return newOSError(err)
+	speed := s.specificBaudrate
+	if err := unix.IoctlSetPointerInt(p.internal.handle, C.IOSSIOSPEED, speed); err != nil {
+		return newPortOSError(err)
 	}
 
 	return nil
